@@ -50,17 +50,26 @@ class NrnFileMorphology(Morphology, DictMixin):
             do_replace_axon=False,
             do_set_nseg=True,
             comment='',
-            replace_axon_hoc=None):
+            replace_axon_hoc=None,
+            nseg_frequency=40,
+            morph_modifiers=None,
+            morph_modifiers_hoc=None):
         """Constructor
 
         Args:
             morphology_path (str): location of the file describing the
                 morphology
-            do_replace_axon(bool): Does the axon need to be replaced by an AIS
-                stub ?
-            replace_axon_hoc(str): String replacement for the 'replace_axon'
-            command in hoc  Must include 'proc replace_axon(){ ... }  If None,
-            the default replace_axon is used in any created hoc files
+            do_replace_axon (bool): Does the axon need to be replaced by an AIS
+                stub with default function ?
+            replace_axon_hoc (str): String replacement for the 'replace_axon'
+                command in hoc  Must include 'proc replace_axon(){ ... }
+                If None,the default replace_axon is used
+            nseg_frequency (float): frequency of nseg
+            do_set_nseg (bool): if True, it will use nseg_frequency
+            morph_modifiers (list): list of functions to modify the icell
+                with (sim, icell) as arguments
+            morph_modifiers_hoc (list): list of hoc strings corresponding
+                to morph_modifiers
         """
         name = os.path.basename(morphology_path)
         super(NrnFileMorphology, self).__init__(name=name, comment=comment)
@@ -69,6 +78,9 @@ class NrnFileMorphology(Morphology, DictMixin):
         self.morphology_path = morphology_path
         self.do_replace_axon = do_replace_axon
         self.do_set_nseg = do_set_nseg
+        self.nseg_frequency = nseg_frequency
+        self.morph_modifiers = morph_modifiers
+        self.morph_modifiers_hoc = morph_modifiers_hoc
 
         if replace_axon_hoc is None:
             self.replace_axon_hoc = self.default_replace_axon_hoc
@@ -126,21 +138,21 @@ class NrnFileMorphology(Morphology, DictMixin):
         if self.do_set_nseg:
             self.set_nseg(icell)
 
-        # TODO replace these two functions with general function users can
-        # specify
         if self.do_replace_axon:
             self.replace_axon(sim=sim, icell=icell)
 
+        if self.morph_modifiers is not None:
+            for morph_modifier in self.morph_modifiers:
+                morph_modifier(sim=sim, icell=icell)
+
     def destroy(self, sim=None):
         """Destroy morphology instantiation"""
         pass
 
-    @staticmethod
-    def set_nseg(icell):
+    def set_nseg(self, icell):
         """Set the nseg of every section"""
-
         for section in icell.all:
-            section.nseg = 1 + 2 * int(section.L / 40)
+            section.nseg = 1 + 2 * int(section.L / self.nseg_frequency)
 
     @staticmethod
     def replace_axon(sim=None, icell=None):
